@@ -1,24 +1,13 @@
 #!/usr/bin/env bash
 
-set -e
+set -ex
 
 HOUDINI_MAJOR="$1"
 GOLD="$2"
-HOUDINI_CLIENT_ID="$4"
-HOUDINI_SECRET_KEY="$5"
-
-if [ "$HOUDINI_CLIENT_ID" == "" ]; then
-    echo "HOUDINI_CLIENT_ID GitHub Action Secret needs to be set to install Houdini builds"
-    exit 0
-fi
-if [ "$HOUDINI_SECRET_KEY" == "" ]; then
-    echo "HOUDINI_SECRET_KEY GitHub Action Secret needs to be set to install Houdini builds"
-    exit 0
-fi
 
 pip install --user requests
 
-python ci/download_houdini.py $HOUDINI_MAJOR $GOLD $HOUDINI_CLIENT_ID $HOUDINI_SECRET_KEY
+python ci/download_houdini.py $HOUDINI_MAJOR $GOLD
 
 # create dir hierarchy
 mkdir -p hou/bin
@@ -34,6 +23,11 @@ tar -xzf houdini.tar.gz
 
 # copy required files into hou dir
 cp houdini_setup* ../hou/.
+
+# report library names
+ls -al dsolib/
+
+# copy required libraries
 cp -r toolkit/cmake ../hou/toolkit/.
 cp -r toolkit/include ../hou/toolkit/.
 cp -r dsolib/libHoudini* ../hou/dsolib/.
@@ -43,15 +37,15 @@ cp -r dsolib/libhboost* ../hou/dsolib/.
 cp -r dsolib/libz* ../hou/dsolib/.
 cp -r dsolib/libbz2* ../hou/dsolib/.
 cp -r dsolib/libtbb* ../hou/dsolib/.
-cp -r dsolib/libHalf* ../hou/dsolib/.
 cp -r dsolib/libjemalloc* ../hou/dsolib/.
 cp -r dsolib/liblzma* ../hou/dsolib/.
+cp -r dsolib/libIex* ../hou/dsolib/.
+cp -r dsolib/libImath* ../hou/dsolib/.
+cp -r dsolib/libIlmThread* ../hou/dsolib/.
 
-# needed for < H18.0 (due to sesitag)
-if [ "$HOUDINI_MAJOR" == "17.0" ] || [ "$HOUDINI_MAJOR" == "17.5" ]; then
-    cp -r bin/app_init* ../hou/bin/.
-    cp -r bin/sesitag* ../hou/bin/.
-    cp -r dsolib/lib* ../hou/dsolib/.
+if [ "$HOUDINI_MAJOR" == "19.0" ]; then
+    cp -r dsolib/libHalf* ../hou/dsolib/.
+    cp -r dsolib/libIlmImf* ../hou/dsolib/.
 fi
 
 # write hou into hou.tar.gz and cleanup
