@@ -8,10 +8,10 @@ set -e
 # the expected VDB installation
 
 cmakelists="
-cmake_minimum_required(VERSION 3.12)
+cmake_minimum_required(VERSION 3.18)
 project(TestInstall LANGUAGES CXX)
 find_package(OpenVDB REQUIRED COMPONENTS openvdb)
-add_executable(test_vdb_print \"../openvdb/openvdb/cmd/openvdb_print.cc\")
+add_executable(test_vdb_print \"../openvdb_cmd/vdb_print/main.cc\")
 target_link_libraries(test_vdb_print OpenVDB::openvdb)
 "
 mkdir tmp
