@@ -139,6 +139,19 @@ AttributeSet::memUsage() const
 }
 
 
+#if OPENVDB_ABI_VERSION_NUMBER >= 10
+size_t
+AttributeSet::memUsageIfLoaded() const
+{
+    size_t bytes = sizeof(*this) + mDescr->memUsage();
+    for (const auto& attr : mAttrs) {
+        bytes += attr->memUsageIfLoaded();
+    }
+    return bytes;
+}
+#endif
+
+
 size_t
 AttributeSet::find(const std::string& name) const
 {
