@@ -25,6 +25,7 @@
 #ifndef OPENVDB_TOOLS_MULTIRESGRID_HAS_BEEN_INCLUDED
 #define OPENVDB_TOOLS_MULTIRESGRID_HAS_BEEN_INCLUDED
 
+#include <openvdb/openvdb.h>
 #include <openvdb/Grid.h>
 #include <openvdb/math/FiniteDifference.h>
 #include <openvdb/math/Math.h>
@@ -33,6 +34,7 @@
 #include <openvdb/Metadata.h>
 #include <openvdb/tree/LeafManager.h>
 #include <openvdb/tree/NodeManager.h>
+
 #include "Interpolation.h"
 #include "Morphology.h"
 #include "Prune.h"
@@ -692,7 +694,7 @@ struct MultiResGrid<TreeType>::MaskOp
         // Create Mask of restruction performed on fineTree
         MaskT mask(fineTree, false, true, TopologyCopy() );
 
-        // Muli-threaded dilation which also linearizes the tree to leaf nodes
+        // Multi-threaded dilation which also linearizes the tree to leaf nodes
         tools::dilateActiveValues(mask, 1, NN_FACE_EDGE_VERTEX, EXPAND_TILES);
 
         // Restriction by injection using thread-local storage of coarse tree masks
@@ -944,6 +946,24 @@ struct MultiResGrid<TreeType>::ProlongateOp
     }
 };// ProlongateOp
 
+
+////////////////////////////////////////
+
+
+// Explicit Template Instantiation
+
+#ifdef OPENVDB_USE_EXPLICIT_INSTANTIATION
+
+#ifdef OPENVDB_INSTANTIATE_MULTIRESGRID
+#include <openvdb/util/ExplicitInstantiation.h>
+#endif
+
+OPENVDB_INSTANTIATE_CLASS MultiResGrid<FloatTree>;
+OPENVDB_INSTANTIATE_CLASS MultiResGrid<DoubleTree>;
+
+#endif // OPENVDB_USE_EXPLICIT_INSTANTIATION
+
+
 } // namespace tools
 } // namespace OPENVDB_VERSION_NAME
 } // namespace openvdb
