@@ -9,6 +9,7 @@
 
 #include <gtest/gtest.h>
 
+#ifdef OPENVDB_USE_DELAYED_LOADING
 #ifdef __clang__
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wunused-macros"
@@ -20,15 +21,8 @@
 #endif
 #include <boost/interprocess/file_mapping.hpp>
 #include <boost/interprocess/mapped_region.hpp>
-#include <tbb/tick_count.h>
 
-#include <atomic>
-#include <cstdio> // for std::remove()
-#include <fstream>
-#include <sstream>
-#include <iostream>
-
-#ifdef _MSC_VER
+#ifdef _WIN32
 #include <boost/interprocess/detail/os_file_functions.hpp> // open_existing_file(), close_file()
 // boost::interprocess::detail was renamed to boost::interprocess::ipcdetail in Boost 1.48.
 // Ensure that both namespaces exist.
@@ -38,8 +32,18 @@ namespace boost { namespace interprocess { namespace detail {} namespace ipcdeta
 #include <sys/types.h> // for struct stat
 #include <sys/stat.h> // for stat()
 #endif
+#endif // OPENVDB_USE_DELAYED_LOADING
+
+#include <tbb/tick_count.h>
+#include <atomic>
+
+#include <cstdio> // for std::remove()
+#include <fstream>
+#include <sstream>
+#include <iostream>
 
 
+#ifdef OPENVDB_USE_DELAYED_LOADING
 /// @brief io::MappedFile has a private constructor, so declare a class that acts as the friend
 class TestMappedFile
 {
@@ -49,6 +53,7 @@ public:
         return openvdb::SharedPtr<openvdb::io::MappedFile>(new openvdb::io::MappedFile(filename));
     }
 };
+#endif
 
 
 /// @brief Functionality similar to openvdb::util::CpuTimer except with prefix padding and no decimals.
@@ -1405,6 +1410,7 @@ TEST_F(TestAttributeArray, testStrided)
     }
 }
 
+#ifdef OPENVDB_USE_DELAYED_LOADING
 void
 TestAttributeArray::testDelayedLoad()
 {
@@ -1420,7 +1426,7 @@ TestAttributeArray::testDelayedLoad()
 
     std::string tempDir;
     if (const char* dir = std::getenv("TMPDIR")) tempDir = dir;
-#ifdef _MSC_VER
+#ifdef _WIN32
     if (tempDir.empty()) {
         char tempDirBuffer[MAX_PATH+1];
         int tempDirLen = GetTempPath(MAX_PATH+1, tempDirBuffer);
@@ -2197,6 +2203,7 @@ TestAttributeArray::testDelayedLoad()
     }
 }
 TEST_F(TestAttributeArray, testDelayedLoad) { testDelayedLoad(); }
+#endif
 
 
 TEST_F(TestAttributeArray, testDefaultValue)
