@@ -555,3 +555,18 @@ TEST_F(TestLeafBool, testMedian)
 //     // since the active voxels were all true to begin with.
 //     EXPECT_TRUE(tree->hasSameTopology(*copyOfTree));
 // }
+
+#if OPENVDB_ABI_VERSION_NUMBER >= 9
+TEST_F(TestLeafBool, testTransientData)
+{
+    LeafType leaf(openvdb::Coord(0, 0, 0), /*background=*/false);
+
+    EXPECT_EQ(openvdb::Index32(0), leaf.transientData());
+    leaf.setTransientData(openvdb::Index32(5));
+    EXPECT_EQ(openvdb::Index32(5), leaf.transientData());
+    LeafType leaf2(leaf);
+    EXPECT_EQ(openvdb::Index32(5), leaf2.transientData());
+    LeafType leaf3 = leaf;
+    EXPECT_EQ(openvdb::Index32(5), leaf3.transientData());
+}
+#endif
