@@ -2,6 +2,7 @@
 // SPDX-License-Identifier: MPL-2.0
 
 #include <openvdb/io/TempFile.h>
+#include <openvdb/math/Math.h>
 #include <openvdb/points/PointDataGrid.h>
 #include <openvdb/points/PointAttribute.h>
 #include <openvdb/points/PointConversion.h>
@@ -119,8 +120,8 @@ genPoints(const int numPoints, const double scale, const bool stride,
     // init
     openvdb::math::Random01 randNumber(0);
     const int n = int(std::sqrt(double(numPoints)));
-    const double xScale = (2.0 * M_PI) / double(n);
-    const double yScale = M_PI / double(n);
+    const double xScale = (2.0 * openvdb::math::pi<double>()) / double(n);
+    const double yScale = openvdb::math::pi<double>() / double(n);
 
     double x, y, theta, phi;
     openvdb::Vec3f pos;
@@ -138,7 +139,7 @@ genPoints(const int numPoints, const double scale, const bool stride,
     AttributeWrapper<float>::Handle uniformHandle(uniform);
     AttributeWrapper<openvdb::Name>::Handle stringHandle(string);
 
-    int i = 0;
+    size_t i = 0;
 
     // loop over a [0 to n) x [0 to n) grid.
     for (int a = 0; a < n; ++a) {
@@ -164,14 +165,14 @@ genPoints(const int numPoints, const double scale, const bool stride,
 
             if (stride)
             {
-                xyzHandle.set(i, 0, i);
-                xyzHandle.set(i, 1, i*i);
-                xyzHandle.set(i, 2, i*i*i);
+                xyzHandle.set(i, 0, static_cast<int>(i));
+                xyzHandle.set(i, 1, static_cast<int>(i*i));
+                xyzHandle.set(i, 2, static_cast<int>(i*i*i));
             }
 
             // add points with even id to the group
             if ((i % 2) == 0) {
-                group.setOffsetOn(i);
+                group.setOffsetOn(static_cast<int>(i));
                 stringHandle.set(i, /*stride*/0, "testA");
             }
             else {
@@ -254,9 +255,7 @@ TEST_F(TestPointConversion, testPointConversion)
 
     // read/write grid to a temp file
 
-    io::TempFile file;
-    const std::string filename = file.filename();
-
+    const std::string filename = "testPointConversion.vdb";
     io::File fileOut(filename);
 
     GridCPtrVec grids;
@@ -408,7 +407,6 @@ TEST_F(TestPointConversion, testPointConversion)
         EXPECT_NEAR(position.buffer()[i*2].z(), pointData[i].position.z(), /*tolerance=*/1e-6);
     }
 
-    file.close();
     std::remove(filename.c_str());
 }
 
@@ -1045,9 +1043,9 @@ TEST_F(TestPointConversion, testComputeVoxelSize)
 
         // Rotate by 45 degrees in X, Y, Z
 
-        transform1->postRotate(M_PI / 4.0, math::X_AXIS);
-        transform1->postRotate(M_PI / 4.0, math::Y_AXIS);
-        transform1->postRotate(M_PI / 4.0, math::Z_AXIS);
+        transform1->postRotate(openvdb::math::pi<double>() / 4.0, math::X_AXIS);
+        transform1->postRotate(openvdb::math::pi<double>() / 4.0, math::Y_AXIS);
+        transform1->postRotate(openvdb::math::pi<double>() / 4.0, math::Z_AXIS);
 
         affineMap1 = transform1->constMap<math::AffineMap>();
         EXPECT_TRUE(affineMap1.get());
@@ -1242,3 +1240,214 @@ TEST_F(TestPointConversion, testPrecision)
         EXPECT_EQ(positionAfterNull.z(), positionAfterFixed16.z());
     }
 }
+
+TEST_F(TestPointConversion, testExample)
+{
+    // this is the example from the documentation using both Vec3R and Vec3f
+
+    { // Vec3R
+        // Create a vector with four point positions.
+        std::vector<openvdb::Vec3R> positions;
+        positions.push_back(openvdb::Vec3R(0, 1, 0));
+        positions.push_back(openvdb::Vec3R(1.5, 3.5, 1));
+        positions.push_back(openvdb::Vec3R(-1, 6, -2));
+        positions.push_back(openvdb::Vec3R(1.1, 1.25, 0.06));
+
+        // The VDB Point-Partioner is used when bucketing points and requires a
+        // specific interface. For convenience, we use the PointAttributeVector
+        // wrapper around an stl vector wrapper here, however it is also possible to
+        // write one for a custom data structure in order to match the interface
+        // required.
+        openvdb::points::PointAttributeVector<openvdb::Vec3R> positionsWrapper(positions);
+
+        // This method computes a voxel-size to match the number of
+        // points / voxel requested. Although it won't be exact, it typically offers
+        // a good balance of memory against performance.
+        int pointsPerVoxel = 8;
+        float voxelSize =
+            openvdb::points::computeVoxelSize(positionsWrapper, pointsPerVoxel);
+
+        // Create a transform using this voxel-size.
+        openvdb::math::Transform::Ptr transform =
+            openvdb::math::Transform::createLinearTransform(voxelSize);
+
+        // Create a PointDataGrid containing these four points and using the
+        // transform given. This function has two template parameters, (1) the codec
+        // to use for storing the position, (2) the grid we want to create
+        // (ie a PointDataGrid).
+        // We use no compression here for the positions.
+        openvdb::points::PointDataGrid::Ptr grid =
+            openvdb::points::createPointDataGrid<openvdb::points::NullCodec,
+                            openvdb::points::PointDataGrid>(positions, *transform);
+
+        // Set the name of the grid
+        grid->setName("Points");
+
+        // Create a VDB file object and write out the grid.
+        openvdb::io::File("mypoints.vdb").write({grid});
+
+        // Create a new VDB file object for reading.
+        openvdb::io::File newFile("mypoints.vdb");
+
+        // Open the file. This reads the file header, but not any grids.
+        newFile.open();
+
+        // Read the grid by name.
+        openvdb::GridBase::Ptr baseGrid = newFile.readGrid("Points");
+        newFile.close();
+
+        // From the example above, "Points" is known to be a PointDataGrid,
+        // so cast the generic grid pointer to a PointDataGrid pointer.
+        grid = openvdb::gridPtrCast<openvdb::points::PointDataGrid>(baseGrid);
+
+        std::vector<Vec3R> resultingPositions;
+
+        // Iterate over all the leaf nodes in the grid.
+        for (auto leafIter = grid->tree().cbeginLeaf(); leafIter; ++leafIter) {
+
+            // Extract the position attribute from the leaf by name (P is position).
+            const openvdb::points::AttributeArray& array =
+                leafIter->constAttributeArray("P");
+
+            // Create a read-only AttributeHandle. Position always uses Vec3f.
+            openvdb::points::AttributeHandle<openvdb::Vec3f> positionHandle(array);
+
+            // Iterate over the point indices in the leaf.
+            for (auto indexIter = leafIter->beginIndexOn(); indexIter; ++indexIter) {
+
+                // Extract the voxel-space position of the point.
+                openvdb::Vec3f voxelPosition = positionHandle.get(*indexIter);
+
+                // Extract the index-space position of the voxel.
+                const openvdb::Vec3d xyz = indexIter.getCoord().asVec3d();
+
+                // Compute the world-space position of the point.
+                openvdb::Vec3f worldPosition =
+                    grid->transform().indexToWorld(voxelPosition + xyz);
+
+                resultingPositions.push_back(worldPosition);
+            }
+        }
+
+        EXPECT_EQ(size_t(4), resultingPositions.size());
+
+        // remap the position order
+
+        std::vector<size_t> remap;
+        remap.push_back(1);
+        remap.push_back(3);
+        remap.push_back(0);
+        remap.push_back(2);
+
+        for (int i = 0; i < 4; i++) {
+            EXPECT_NEAR(positions[i].x(), resultingPositions[remap[i]].x(), /*tolerance=*/1e-6);
+            EXPECT_NEAR(positions[i].y(), resultingPositions[remap[i]].y(), /*tolerance=*/1e-6);
+            EXPECT_NEAR(positions[i].z(), resultingPositions[remap[i]].z(), /*tolerance=*/1e-6);
+        }
+
+        remove("mypoints.vdb");
+    }
+
+    { // Vec3f
+        // Create a vector with four point positions.
+        std::vector<openvdb::Vec3f> positions;
+        positions.push_back(openvdb::Vec3f(0.0f, 1.0f, 0.0f));
+        positions.push_back(openvdb::Vec3f(1.5f, 3.5f, 1.0f));
+        positions.push_back(openvdb::Vec3f(-1.0f, 6.0f, -2.0f));
+        positions.push_back(openvdb::Vec3f(1.1f, 1.25f, 0.06f));
+
+        // The VDB Point-Partioner is used when bucketing points and requires a
+        // specific interface. For convenience, we use the PointAttributeVector
+        // wrapper around an stl vector wrapper here, however it is also possible to
+        // write one for a custom data structure in order to match the interface
+        // required.
+        openvdb::points::PointAttributeVector<openvdb::Vec3f> positionsWrapper(positions);
+
+        // This method computes a voxel-size to match the number of
+        // points / voxel requested. Although it won't be exact, it typically offers
+        // a good balance of memory against performance.
+        int pointsPerVoxel = 8;
+        float voxelSize =
+            openvdb::points::computeVoxelSize(positionsWrapper, pointsPerVoxel);
+
+        // Create a transform using this voxel-size.
+        openvdb::math::Transform::Ptr transform =
+            openvdb::math::Transform::createLinearTransform(voxelSize);
+
+        // Create a PointDataGrid containing these four points and using the
+        // transform given. This function has two template parameters, (1) the codec
+        // to use for storing the position, (2) the grid we want to create
+        // (ie a PointDataGrid).
+        // We use no compression here for the positions.
+        openvdb::points::PointDataGrid::Ptr grid =
+            openvdb::points::createPointDataGrid<openvdb::points::NullCodec,
+                            openvdb::points::PointDataGrid>(positions, *transform);
+
+        // Set the name of the grid
+        grid->setName("Points");
+
+        // Create a VDB file object and write out the grid.
+        openvdb::io::File("mypoints.vdb").write({grid});
+
+        // Create a new VDB file object for reading.
+        openvdb::io::File newFile("mypoints.vdb");
+
+        // Open the file. This reads the file header, but not any grids.
+        newFile.open();
+
+        // Read the grid by name.
+        openvdb::GridBase::Ptr baseGrid = newFile.readGrid("Points");
+        newFile.close();
+
+        // From the example above, "Points" is known to be a PointDataGrid,
+        // so cast the generic grid pointer to a PointDataGrid pointer.
+        grid = openvdb::gridPtrCast<openvdb::points::PointDataGrid>(baseGrid);
+
+        std::vector<Vec3f> resultingPositions;
+
+        // Iterate over all the leaf nodes in the grid.
+        for (auto leafIter = grid->tree().cbeginLeaf(); leafIter; ++leafIter) {
+
+            // Extract the position attribute from the leaf by name (P is position).
+            const openvdb::points::AttributeArray& array =
+                leafIter->constAttributeArray("P");
+
+            // Create a read-only AttributeHandle. Position always uses Vec3f.
+            openvdb::points::AttributeHandle<openvdb::Vec3f> positionHandle(array);
+
+            // Iterate over the point indices in the leaf.
+            for (auto indexIter = leafIter->beginIndexOn(); indexIter; ++indexIter) {
+
+                // Extract the voxel-space position of the point.
+                openvdb::Vec3f voxelPosition = positionHandle.get(*indexIter);
+
+                // Extract the index-space position of the voxel.
+                const openvdb::Vec3d xyz = indexIter.getCoord().asVec3d();
+
+                // Compute the world-space position of the point.
+                openvdb::Vec3f worldPosition =
+                    grid->transform().indexToWorld(voxelPosition + xyz);
+
+                resultingPositions.push_back(worldPosition);
+            }
+        }
+
+        EXPECT_EQ(size_t(4), resultingPositions.size());
+
+        // remap the position order
+
+        std::vector<size_t> remap;
+        remap.push_back(1);
+        remap.push_back(3);
+        remap.push_back(0);
+        remap.push_back(2);
+
+        for (int i = 0; i < 4; i++) {
+            EXPECT_NEAR(positions[i].x(), resultingPositions[remap[i]].x(), /*tolerance=*/1e-6f);
+            EXPECT_NEAR(positions[i].y(), resultingPositions[remap[i]].y(), /*tolerance=*/1e-6f);
+            EXPECT_NEAR(positions[i].z(), resultingPositions[remap[i]].z(), /*tolerance=*/1e-6f);
+        }
+
+        remove("mypoints.vdb");
+    }
+}
