@@ -80,14 +80,6 @@ TEST_F(TestPointScatter, testUniformPointScatter)
         EXPECT_EQ(Index64(27), points->activeVoxelCount());
         EXPECT_EQ(total, pointCount(points->tree()));
     }
-    {
-        StringGrid grid;
-        grid.sparseFill(boxBounds, "", /*active*/true);
-        auto points = points::uniformPointScatter(grid, total);
-        EXPECT_EQ(Index32(8), points->tree().leafCount());
-        EXPECT_EQ(Index64(27), points->activeVoxelCount());
-        EXPECT_EQ(total, pointCount(points->tree()));
-    }
     {
         Vec3DGrid grid;
         grid.sparseFill(boxBounds, Vec3d(), /*active*/true);
@@ -314,14 +306,6 @@ TEST_F(TestPointScatter, testDenseUniformPointScatter)
         EXPECT_EQ(Index64(27), points->activeVoxelCount());
         EXPECT_EQ(Index64(pointsPerVoxel * 27), pointCount(points->tree()));
     }
-    {
-        StringGrid grid;
-        grid.sparseFill(boxBounds, "", /*active*/true);
-        auto points = points::denseUniformPointScatter(grid, pointsPerVoxel);
-        EXPECT_EQ(Index32(8), points->tree().leafCount());
-        EXPECT_EQ(Index64(27), points->activeVoxelCount());
-        EXPECT_EQ(Index64(pointsPerVoxel * 27), pointCount(points->tree()));
-    }
     {
         Vec3DGrid grid;
         grid.sparseFill(boxBounds, Vec3d(), /*active*/true);
