@@ -12,7 +12,7 @@
 #include <string>
 #include <vector>
 
-#include "gtest/gtest.h"
+#include <gtest/gtest.h>
 
 int
 main(int argc, char *argv[])
