@@ -22,13 +22,15 @@ OPENVDB_USE_VERSION_NAMESPACE
 namespace OPENVDB_VERSION_NAME {
 
 #define OPENVDB_AX_EXCEPTION(_classname) \
-class OPENVDB_API _classname: public Exception \
+class _classname: public Exception \
 { \
 public: \
     _classname() noexcept: Exception( #_classname ) {} \
     explicit _classname(const std::string& msg) noexcept: Exception( #_classname , &msg) {} \
 }
 
+OPENVDB_AX_EXCEPTION(CLIError);
+
 // @note: Compilation errors due to invalid AX code should be collected using a separate logging system.
 //   These errors are only thrown upon encountering fatal errors within the compiler/executables themselves
 OPENVDB_AX_EXCEPTION(AXTokenError);
