@@ -18,9 +18,9 @@
 #include "Utils.h"
 #include "PointLeafLocalData.h"
 
-#include "../ast/Tokens.h"
-#include "../compiler/CompilerOptions.h"
-#include "../Exceptions.h"
+#include "openvdb_ax/ast/Tokens.h"
+#include "openvdb_ax/compiler/CompilerOptions.h"
+#include "openvdb_ax/Exceptions.h"
 
 #include <openvdb/openvdb.h>
 #include <openvdb/points/PointDataGrid.h>
@@ -66,6 +66,9 @@ groupHandle(const std::string& name, void** groupHandles, const void* const data
 
 }
 
+///////////////////////////////////////////////////////////////////////////////
+///////////////////////////////////////////////////////////////////////////////
+
 inline FunctionGroup::UniquePtr ax_ingroup(const FunctionOptions& op)
 {
     static auto ingroup =
@@ -182,7 +185,7 @@ inline FunctionGroup::UniquePtr axeditgroup(const FunctionOptions& op)
             codegen_internal::PointLeafLocalData* const leafData =
                 static_cast<codegen_internal::PointLeafLocalData*>(leafDataPtr);
 
-            // If we are setting membership and the handle doesnt exist, create in in
+            // If we are setting membership and the handle doesn't exist, create in in
             // the set of new data thats being added
             if (!flag && !leafData->hasGroup(nameStr)) return;
             handle = leafData->getOrInsert(nameStr);
