@@ -19,6 +19,8 @@ public:
     CPPUNIT_TEST(testTreeExecutionLevel);
     CPPUNIT_TEST(testActiveTileStreaming);
     CPPUNIT_TEST(testCompilerCases);
+    CPPUNIT_TEST(testExecuteBindings);
+    CPPUNIT_TEST(testCLI);
     CPPUNIT_TEST_SUITE_END();
 
     void testConstructionDestruction();
@@ -26,6 +28,8 @@ public:
     void testTreeExecutionLevel();
     void testActiveTileStreaming();
     void testCompilerCases();
+    void testExecuteBindings();
+    void testCLI();
 };
 
 CPPUNIT_TEST_SUITE_REGISTRATION(TestVolumeExecutable);
@@ -574,10 +578,13 @@ TestVolumeExecutable::testActiveTileStreaming()
     }
 
     // test spatially varying voxelization for string grids which use specialized implementations
+    // Note: StringGrids are no longer registered by default
     {
-        openvdb::StringGrid grid;
+        using StringTree = openvdb::tree::Tree4<std::string, 5, 4, 3>::Type;
+        using StringGrid = openvdb::Grid<openvdb::tree::Tree4<std::string, 5, 4, 3>::Type>;
+        StringGrid grid;
         grid.setName("test");
-        openvdb::StringTree& tree = grid.tree();
+        StringTree& tree = grid.tree();
         tree.addTile(2, openvdb::Coord(NodeT1::DIM*0, 0, 0), "foo", /*active*/true); // NodeT1 tile
         tree.addTile(2, openvdb::Coord(NodeT1::DIM*1, 0, 0), "foo", /*active*/true); // NodeT1 tile
         tree.addTile(2, openvdb::Coord(NodeT1::DIM*2, 0, 0), "foo", /*active*/true); // NodeT1 tile
@@ -594,14 +601,14 @@ TestVolumeExecutable::testActiveTileStreaming()
             executable->getActiveTileStreaming("empty", openvdb::ax::ast::tokens::CoreType::FLOAT));
         executable->getTreeExecutionLevel(min,max);
         CPPUNIT_ASSERT_EQUAL(openvdb::Index(0), min);
-        CPPUNIT_ASSERT_EQUAL(openvdb::Index(openvdb::StringTree::DEPTH-1), max);
+        CPPUNIT_ASSERT_EQUAL(openvdb::Index(StringTree::DEPTH-1), max);
 
         executable->execute(grid);
 
         const openvdb::Index64 face = NodeT1::DIM * NodeT1::DIM; // face voxel count of NodeT2 x==0
         const openvdb::Index64 leafs = // expected leaf nodes that need to be created
-            (face * openvdb::StringTree::LeafNodeType::DIM) /
-            openvdb::StringTree::LeafNodeType::NUM_VOXELS;
+            (face * StringTree::LeafNodeType::DIM) /
+            StringTree::LeafNodeType::NUM_VOXELS;
 
         // number of child nodes in NodeT1;
         const openvdb::Index64 n1ChildAxisCount = NodeT1::DIM / NodeT1::getChildDim();
@@ -613,10 +620,10 @@ TestVolumeExecutable::testActiveTileStreaming()
 
         CPPUNIT_ASSERT_EQUAL(openvdb::Index32(leafs), tree.leafCount());
         CPPUNIT_ASSERT_EQUAL(openvdb::Index64(tiles), tree.activeTileCount());
-        CPPUNIT_ASSERT_EQUAL(int(openvdb::StringTree::DEPTH-3), tree.getValueDepth(openvdb::Coord(NodeT1::DIM*1, 0, 0)));
-        CPPUNIT_ASSERT_EQUAL(int(openvdb::StringTree::DEPTH-3), tree.getValueDepth(openvdb::Coord(NodeT1::DIM*2, 0, 0)));
-        CPPUNIT_ASSERT_EQUAL(int(openvdb::StringTree::DEPTH-3), tree.getValueDepth(openvdb::Coord(NodeT1::DIM*3, 0, 0)));
-        CPPUNIT_ASSERT_EQUAL(int(openvdb::StringTree::DEPTH-2), tree.getValueDepth(openvdb::Coord(NodeT2::DIM)));
+        CPPUNIT_ASSERT_EQUAL(int(StringTree::DEPTH-3), tree.getValueDepth(openvdb::Coord(NodeT1::DIM*1, 0, 0)));
+        CPPUNIT_ASSERT_EQUAL(int(StringTree::DEPTH-3), tree.getValueDepth(openvdb::Coord(NodeT1::DIM*2, 0, 0)));
+        CPPUNIT_ASSERT_EQUAL(int(StringTree::DEPTH-3), tree.getValueDepth(openvdb::Coord(NodeT1::DIM*3, 0, 0)));
+        CPPUNIT_ASSERT_EQUAL(int(StringTree::DEPTH-2), tree.getValueDepth(openvdb::Coord(NodeT2::DIM)));
         CPPUNIT_ASSERT_EQUAL((openvdb::Index64(NodeT1::NUM_VOXELS)*4) +
             openvdb::Index64(NodeT0::NUM_VOXELS), tree.activeVoxelCount());
 
@@ -764,7 +771,7 @@ TestVolumeExecutable::testCompilerCases()
         // with string only
         CPPUNIT_ASSERT(static_cast<bool>(compiler->compile<openvdb::ax::VolumeExecutable>("int i;")));
         CPPUNIT_ASSERT_THROW(compiler->compile<openvdb::ax::VolumeExecutable>("i;"), openvdb::AXCompilerError);
-        CPPUNIT_ASSERT_THROW(compiler->compile<openvdb::ax::VolumeExecutable>("i"), openvdb::AXCompilerError);
+        CPPUNIT_ASSERT_THROW(compiler->compile<openvdb::ax::VolumeExecutable>("i"), openvdb::AXSyntaxError);
         // with AST only
         auto ast = openvdb::ax::ast::parse("i;");
         CPPUNIT_ASSERT_THROW(compiler->compile<openvdb::ax::VolumeExecutable>(*ast), openvdb::AXCompilerError);
@@ -870,3 +877,410 @@ TestVolumeExecutable::testCompilerCases()
     logger.clear();
 }
 
+void
+TestVolumeExecutable::testExecuteBindings()
+{
+    openvdb::ax::Compiler::UniquePtr compiler = openvdb::ax::Compiler::create();
+
+    openvdb::ax::AttributeBindings bindings;
+    bindings.set("b", "a"); // bind b to a
+
+    {
+        // multi volumes
+        openvdb::FloatGrid::Ptr f1(new openvdb::FloatGrid);
+        f1->setName("a");
+        f1->tree().setValueOn({0,0,0}, 0.0f);
+        std::vector<openvdb::GridBase::Ptr> v { f1 };
+        openvdb::ax::VolumeExecutable::Ptr executable =
+            compiler->compile<openvdb::ax::VolumeExecutable>("@b = 1.0f;");
+
+        CPPUNIT_ASSERT(executable);
+        executable->setAttributeBindings(bindings);
+        executable->setCreateMissing(false);
+        CPPUNIT_ASSERT_NO_THROW(executable->execute(v));
+        CPPUNIT_ASSERT_EQUAL(1.0f, f1->tree().getValue({0,0,0}));
+    }
+
+    // binding to existing attribute AND not binding to attribute
+    {
+        openvdb::FloatGrid::Ptr f1(new openvdb::FloatGrid);
+        openvdb::FloatGrid::Ptr f2(new openvdb::FloatGrid);
+        f1->setName("a");
+        f2->setName("c");
+        f1->tree().setValueOn({0,0,0}, 0.0f);
+        f2->tree().setValueOn({0,0,0}, 0.0f);
+        std::vector<openvdb::GridBase::Ptr> v { f1, f2 };
+        openvdb::ax::VolumeExecutable::Ptr executable =
+            compiler->compile<openvdb::ax::VolumeExecutable>("@b = 1.0f; @c = 2.0f;");
+
+        CPPUNIT_ASSERT(executable);
+        executable->setAttributeBindings(bindings);
+        executable->setCreateMissing(false);
+        CPPUNIT_ASSERT_NO_THROW(executable->execute(v));
+        CPPUNIT_ASSERT_EQUAL(1.0f, f1->tree().getValue({0,0,0}));
+        CPPUNIT_ASSERT_EQUAL(2.0f, f2->tree().getValue({0,0,0}));
+    }
+
+    // binding to new created attribute AND not binding to new created attribute
+    {
+        openvdb::FloatGrid::Ptr f2(new openvdb::FloatGrid);
+        f2->setName("c");
+        f2->tree().setValueOn({0,0,0}, 0.0f);
+        std::vector<openvdb::GridBase::Ptr> v { f2 };
+        openvdb::ax::VolumeExecutable::Ptr executable =
+            compiler->compile<openvdb::ax::VolumeExecutable>("@b = 1.0f; @c = 2.0f;");
+
+        CPPUNIT_ASSERT(executable);
+        executable->setAttributeBindings(bindings);
+        CPPUNIT_ASSERT_NO_THROW(executable->execute(v));
+        CPPUNIT_ASSERT_EQUAL(2.0f, f2->tree().getValue({0,0,0}));
+        CPPUNIT_ASSERT_EQUAL(size_t(2), v.size());
+    }
+
+    // binding to non existent attribute, not creating, error
+    {
+        openvdb::FloatGrid::Ptr f2(new openvdb::FloatGrid);
+        f2->setName("c");
+        f2->tree().setValueOn({0,0,0}, 0.0f);
+        std::vector<openvdb::GridBase::Ptr> v { f2 };
+        openvdb::ax::VolumeExecutable::Ptr executable =
+            compiler->compile<openvdb::ax::VolumeExecutable>("@b = 1.0f; @c = 2.0f;");
+
+        CPPUNIT_ASSERT(executable);
+        executable->setAttributeBindings(bindings);
+        executable->setCreateMissing(false);
+        CPPUNIT_ASSERT_THROW(executable->execute(v), openvdb::AXExecutionError);
+    }
+
+    // trying to bind to an attribute and use the original attribute name at same time
+    {
+        openvdb::FloatGrid::Ptr f2(new openvdb::FloatGrid);
+        f2->setName("c");
+        f2->tree().setValueOn({0,0,0}, 0.0f);
+        std::vector<openvdb::GridBase::Ptr> v { f2 };
+        openvdb::ax::VolumeExecutable::Ptr executable =
+            compiler->compile<openvdb::ax::VolumeExecutable>("@b = 1.0f; @c = 2.0f;");
+        CPPUNIT_ASSERT(executable);
+        openvdb::ax::AttributeBindings bindings;
+        bindings.set("b","c"); // bind b to c
+        CPPUNIT_ASSERT_THROW(executable->setAttributeBindings(bindings), openvdb::AXExecutionError);
+   }
+
+    // swap ax and data attributes with bindings
+    {
+        openvdb::FloatGrid::Ptr f2(new openvdb::FloatGrid);
+        f2->setName("c");
+        f2->tree().setValueOn({0,0,0}, 0.0f);
+        std::vector<openvdb::GridBase::Ptr> v { f2 };
+        openvdb::ax::VolumeExecutable::Ptr executable =
+            compiler->compile<openvdb::ax::VolumeExecutable>("@b = 1.0f; @c = 2.0f;");
+        CPPUNIT_ASSERT(executable);
+        openvdb::ax::AttributeBindings bindings;
+        bindings.set("b","c"); // bind b to c
+        bindings.set("c","b"); // bind c to b
+
+        CPPUNIT_ASSERT_NO_THROW(executable->setAttributeBindings(bindings));
+        CPPUNIT_ASSERT_NO_THROW(executable->execute(v));
+        CPPUNIT_ASSERT_EQUAL(1.0f, f2->tree().getValue({0,0,0}));
+    }
+
+    // test setting bindings and then resetting some of those bindings on the same executable
+    {
+        openvdb::ax::VolumeExecutable::Ptr executable =
+            compiler->compile<openvdb::ax::VolumeExecutable>("@b = 1.0f; @a = 2.0f; @c = 3.0f;");
+        CPPUNIT_ASSERT(executable);
+        openvdb::ax::AttributeBindings bindings;
+        bindings.set("b","a"); // bind b to a
+        bindings.set("c","b"); // bind c to b
+        bindings.set("a","c"); // bind a to c
+        CPPUNIT_ASSERT_NO_THROW(executable->setAttributeBindings(bindings));
+
+        bindings.set("a","b"); // bind a to b
+        bindings.set("b","a"); // bind a to b
+        CPPUNIT_ASSERT(!bindings.dataNameBoundTo("c")); // c should be unbound
+        // check that the set call resets c to c
+        CPPUNIT_ASSERT_NO_THROW(executable->setAttributeBindings(bindings));
+        const openvdb::ax::AttributeBindings& bindingsOnExecutable = executable->getAttributeBindings();
+        CPPUNIT_ASSERT(bindingsOnExecutable.isBoundAXName("c"));
+        CPPUNIT_ASSERT_EQUAL(*bindingsOnExecutable.dataNameBoundTo("c"), std::string("c"));
+    }
+}
+
+void
+TestVolumeExecutable::testCLI()
+{
+    using namespace openvdb;
+    using CLI = openvdb::ax::VolumeExecutable::CLI;
+
+    struct UnusedCLIParam : public openvdb::Exception {
+        UnusedCLIParam() noexcept: Exception( "UnusedCLIParam" ) {} \
+        explicit UnusedCLIParam(const std::string& msg) noexcept: Exception( "UnusedCLIParam" , &msg) {}
+    };
+
+    auto CreateCLI = [](const char* c, bool throwIfUnused = true)
+    {
+        std::vector<std::string> strs;
+        const char* s = c;
+        while (*c != '\0') {
+            if (*c == ' ') {
+                strs.emplace_back(std::string(s, c-s));
+                ++c;
+                s = c;
+            }
+            else {
+                ++c;
+            }
+        }
+        if (*s != '\0') strs.emplace_back(std::string(s, c-s));
+
+        std::vector<const char*> args;
+        for (auto& str : strs) args.emplace_back(str.c_str());
+
+        std::unique_ptr<bool[]> flags(new bool[args.size()]);
+        std::fill(flags.get(), flags.get()+args.size(), false);
+
+        auto cli = CLI::create(args.size(), args.data(), flags.get());
+        if (throwIfUnused) {
+            for (size_t i = 0; i < args.size(); ++i) {
+                if (!flags[i]) OPENVDB_THROW(UnusedCLIParam, "unused param");
+            }
+        }
+        return cli;
+    };
+
+    ax::Compiler::UniquePtr compiler = ax::Compiler::create();
+
+    auto defaultExe = compiler->compile<openvdb::ax::VolumeExecutable>("");
+    Index defaultMinLevel, defaultMaxLevel;
+    defaultExe->getTreeExecutionLevel(defaultMinLevel, defaultMaxLevel);
+    const auto defaultCreateMissing = defaultExe->getCreateMissing();
+    const auto defaultTileStream = defaultExe->getActiveTileStreaming();
+    const auto defaultValueIter = defaultExe->getValueIterator();
+    const auto defaultGrain = defaultExe->getGrainSize();
+    const auto defaultTileGrain = defaultExe->getActiveTileStreamingGrainSize();
+    const auto defaultBindings = defaultExe->getAttributeBindings();
+
+    CPPUNIT_ASSERT_THROW(CreateCLI("--unknown"), UnusedCLIParam);
+    CPPUNIT_ASSERT_THROW(CreateCLI("-unknown"), UnusedCLIParam);
+    CPPUNIT_ASSERT_THROW(CreateCLI("-"), UnusedCLIParam);
+    CPPUNIT_ASSERT_THROW(CreateCLI("--"), UnusedCLIParam);
+    CPPUNIT_ASSERT_THROW(CreateCLI("-- "), UnusedCLIParam);
+
+    {
+        CLI cli = CreateCLI("");
+        auto exe = compiler->compile<openvdb::ax::VolumeExecutable>("");
+        CPPUNIT_ASSERT_NO_THROW(exe->setSettingsFromCLI(cli));
+
+        Index min,max;
+        exe->getTreeExecutionLevel(min, max);
+        CPPUNIT_ASSERT_EQUAL(defaultMinLevel, min);
+        CPPUNIT_ASSERT_EQUAL(defaultMaxLevel, max);
+        CPPUNIT_ASSERT_EQUAL(defaultCreateMissing, exe->getCreateMissing());
+        CPPUNIT_ASSERT_EQUAL(defaultTileStream, exe->getActiveTileStreaming());
+        CPPUNIT_ASSERT_EQUAL(defaultValueIter, exe->getValueIterator());
+        CPPUNIT_ASSERT_EQUAL(defaultGrain, exe->getGrainSize());
+        CPPUNIT_ASSERT_EQUAL(defaultTileGrain, exe->getActiveTileStreamingGrainSize());
+        CPPUNIT_ASSERT_EQUAL(defaultBindings, exe->getAttributeBindings());
+    }
+
+    // --create-missing
+    {
+        CPPUNIT_ASSERT_THROW(CreateCLI("--create-missing"), openvdb::CLIError);
+        CPPUNIT_ASSERT_THROW(CreateCLI("--create-missing invalid"), openvdb::CLIError);
+        CPPUNIT_ASSERT_THROW(CreateCLI("--create-missing --group test"), openvdb::CLIError);
+
+        CLI cli = CreateCLI("--create-missing ON");
+        auto exe = compiler->compile<openvdb::ax::VolumeExecutable>("");
+        CPPUNIT_ASSERT_NO_THROW(exe->setSettingsFromCLI(cli));
+
+        Index min,max;
+        exe->getTreeExecutionLevel(min, max);
+        CPPUNIT_ASSERT_EQUAL(defaultMinLevel, min);
+        CPPUNIT_ASSERT_EQUAL(defaultMaxLevel, max);
+        CPPUNIT_ASSERT_EQUAL(true, exe->getCreateMissing());
+        CPPUNIT_ASSERT_EQUAL(defaultTileStream, exe->getActiveTileStreaming());
+        CPPUNIT_ASSERT_EQUAL(defaultValueIter, exe->getValueIterator());
+        CPPUNIT_ASSERT_EQUAL(defaultGrain, exe->getGrainSize());
+        CPPUNIT_ASSERT_EQUAL(defaultTileGrain, exe->getActiveTileStreamingGrainSize());
+        CPPUNIT_ASSERT_EQUAL(defaultBindings, exe->getAttributeBindings());
+    }
+
+    // --tile-stream
+    {
+        CPPUNIT_ASSERT_THROW(CreateCLI("--tile-stream"), openvdb::CLIError);
+        CPPUNIT_ASSERT_THROW(CreateCLI("--tile-stream invalid"), openvdb::CLIError);
+        CPPUNIT_ASSERT_THROW(CreateCLI("--tile-stream --group test"), openvdb::CLIError);
+
+        CLI cli = CreateCLI("--tile-stream ON");
+        auto exe = compiler->compile<openvdb::ax::VolumeExecutable>("");
+        CPPUNIT_ASSERT_NO_THROW(exe->setSettingsFromCLI(cli));
+
+        Index min,max;
+        exe->getTreeExecutionLevel(min, max);
+        CPPUNIT_ASSERT_EQUAL(defaultMinLevel, min);
+        CPPUNIT_ASSERT_EQUAL(defaultMaxLevel, max);
+        CPPUNIT_ASSERT_EQUAL(defaultCreateMissing, exe->getCreateMissing());
+        CPPUNIT_ASSERT_EQUAL(openvdb::ax::VolumeExecutable::Streaming::ON, exe->getActiveTileStreaming());
+        CPPUNIT_ASSERT_EQUAL(defaultValueIter, exe->getValueIterator());
+        CPPUNIT_ASSERT_EQUAL(defaultGrain, exe->getGrainSize());
+        CPPUNIT_ASSERT_EQUAL(defaultTileGrain, exe->getActiveTileStreamingGrainSize());
+        CPPUNIT_ASSERT_EQUAL(defaultBindings, exe->getAttributeBindings());
+    }
+
+    // --node-iter
+    {
+        CPPUNIT_ASSERT_THROW(CreateCLI("--node-iter"), openvdb::CLIError);
+        CPPUNIT_ASSERT_THROW(CreateCLI("--node-iter invalid"), openvdb::CLIError);
+        CPPUNIT_ASSERT_THROW(CreateCLI("--node-iter --group test"), openvdb::CLIError);
+
+        CLI cli = CreateCLI("--node-iter ALL");
+        auto exe = compiler->compile<openvdb::ax::VolumeExecutable>("");
+        CPPUNIT_ASSERT_NO_THROW(exe->setSettingsFromCLI(cli));
+
+        Index min,max;
+        exe->getTreeExecutionLevel(min, max);
+        CPPUNIT_ASSERT_EQUAL(defaultMinLevel, min);
+        CPPUNIT_ASSERT_EQUAL(defaultMaxLevel, max);
+        CPPUNIT_ASSERT_EQUAL(defaultCreateMissing, exe->getCreateMissing());
+        CPPUNIT_ASSERT_EQUAL(defaultTileStream, exe->getActiveTileStreaming());
+        CPPUNIT_ASSERT_EQUAL(openvdb::ax::VolumeExecutable::IterType::ALL, exe->getValueIterator());
+        CPPUNIT_ASSERT_EQUAL(defaultGrain, exe->getGrainSize());
+        CPPUNIT_ASSERT_EQUAL(defaultTileGrain, exe->getActiveTileStreamingGrainSize());
+        CPPUNIT_ASSERT_EQUAL(defaultBindings, exe->getAttributeBindings());
+    }
+
+    // --tree-level
+    {
+        CPPUNIT_ASSERT_THROW(CreateCLI("--tree-level"), openvdb::CLIError);
+        CPPUNIT_ASSERT_THROW(CreateCLI("--tree-level invalid"), openvdb::CLIError);
+        CPPUNIT_ASSERT_THROW(CreateCLI("--tree-level --group test"), openvdb::CLIError);
+
+        CLI cli = CreateCLI("--tree-level 0");
+        auto exe = compiler->compile<openvdb::ax::VolumeExecutable>("");
+        CPPUNIT_ASSERT_NO_THROW(exe->setSettingsFromCLI(cli));
+
+        Index min,max;
+        exe->getTreeExecutionLevel(min, max);
+        CPPUNIT_ASSERT_EQUAL(min, Index(0));
+        CPPUNIT_ASSERT_EQUAL(defaultMaxLevel, max);
+        CPPUNIT_ASSERT_EQUAL(defaultCreateMissing, exe->getCreateMissing());
+        CPPUNIT_ASSERT_EQUAL(defaultTileStream, exe->getActiveTileStreaming());
+        CPPUNIT_ASSERT_EQUAL(defaultValueIter, exe->getValueIterator());
+        CPPUNIT_ASSERT_EQUAL(defaultGrain, exe->getGrainSize());
+        CPPUNIT_ASSERT_EQUAL(defaultTileGrain, exe->getActiveTileStreamingGrainSize());
+        CPPUNIT_ASSERT_EQUAL(defaultBindings, exe->getAttributeBindings());
+
+        cli = CreateCLI("--tree-level 1:2");
+        CPPUNIT_ASSERT_NO_THROW(exe->setSettingsFromCLI(cli));
+
+        exe->getTreeExecutionLevel(min, max);
+        CPPUNIT_ASSERT_EQUAL(min, Index(1));
+        CPPUNIT_ASSERT_EQUAL(max, Index(2));
+        CPPUNIT_ASSERT_EQUAL(defaultCreateMissing, exe->getCreateMissing());
+        CPPUNIT_ASSERT_EQUAL(defaultTileStream, exe->getActiveTileStreaming());
+        CPPUNIT_ASSERT_EQUAL(defaultValueIter, exe->getValueIterator());
+        CPPUNIT_ASSERT_EQUAL(defaultGrain, exe->getGrainSize());
+        CPPUNIT_ASSERT_EQUAL(defaultTileGrain, exe->getActiveTileStreamingGrainSize());
+        CPPUNIT_ASSERT_EQUAL(defaultBindings, exe->getAttributeBindings());
+    }
+
+    // --tree-level
+    {
+        CPPUNIT_ASSERT_THROW(CreateCLI("--volume-grain"), openvdb::CLIError);
+        CPPUNIT_ASSERT_THROW(CreateCLI("--volume-grain invalid"), openvdb::CLIError);
+        CPPUNIT_ASSERT_THROW(CreateCLI("--volume-grain --group test"), openvdb::CLIError);
+
+        CLI cli = CreateCLI("--volume-grain 0");
+        auto exe = compiler->compile<openvdb::ax::VolumeExecutable>("");
+        CPPUNIT_ASSERT_NO_THROW(exe->setSettingsFromCLI(cli));
+
+        Index min,max;
+        exe->getTreeExecutionLevel(min, max);
+        CPPUNIT_ASSERT_EQUAL(defaultMinLevel, min);
+        CPPUNIT_ASSERT_EQUAL(defaultMaxLevel, max);
+        CPPUNIT_ASSERT_EQUAL(defaultCreateMissing, exe->getCreateMissing());
+        CPPUNIT_ASSERT_EQUAL(defaultTileStream, exe->getActiveTileStreaming());
+        CPPUNIT_ASSERT_EQUAL(defaultValueIter, exe->getValueIterator());
+        CPPUNIT_ASSERT_EQUAL(size_t(0), exe->getGrainSize());
+        CPPUNIT_ASSERT_EQUAL(defaultTileGrain, exe->getActiveTileStreamingGrainSize());
+        CPPUNIT_ASSERT_EQUAL(defaultBindings, exe->getAttributeBindings());
+
+        cli = CreateCLI("--volume-grain 1:2");
+        CPPUNIT_ASSERT_NO_THROW(exe->setSettingsFromCLI(cli));
+
+        exe->getTreeExecutionLevel(min, max);
+        CPPUNIT_ASSERT_EQUAL(defaultMinLevel, min);
+        CPPUNIT_ASSERT_EQUAL(defaultMaxLevel, max);
+        CPPUNIT_ASSERT_EQUAL(defaultCreateMissing, exe->getCreateMissing());
+        CPPUNIT_ASSERT_EQUAL(defaultTileStream, exe->getActiveTileStreaming());
+        CPPUNIT_ASSERT_EQUAL(defaultValueIter, exe->getValueIterator());
+        CPPUNIT_ASSERT_EQUAL(size_t(1), exe->getGrainSize());
+        CPPUNIT_ASSERT_EQUAL(size_t(2), exe->getActiveTileStreamingGrainSize());
+        CPPUNIT_ASSERT_EQUAL(defaultBindings, exe->getAttributeBindings());
+    }
+
+    // --bindings
+    {
+        CPPUNIT_ASSERT_THROW(CreateCLI("--bindings"), openvdb::CLIError);
+        CPPUNIT_ASSERT_THROW(CreateCLI("--bindings :"), openvdb::CLIError);
+        CPPUNIT_ASSERT_THROW(CreateCLI("--bindings ,"), openvdb::CLIError);
+        CPPUNIT_ASSERT_THROW(CreateCLI("--bindings a:"), openvdb::CLIError);
+        CPPUNIT_ASSERT_THROW(CreateCLI("--bindings a,b"), openvdb::CLIError);
+        CPPUNIT_ASSERT_THROW(CreateCLI("--bindings :b"), openvdb::CLIError);
+        CPPUNIT_ASSERT_THROW(CreateCLI("--bindings ,a:b"), openvdb::CLIError);
+        CPPUNIT_ASSERT_THROW(CreateCLI("--bindings --create-missing ON"), openvdb::CLIError);
+
+        CLI cli = CreateCLI("--bindings a:b,c:d,12:13");
+        ax::AttributeBindings bindings;
+        bindings.set("a", "b");
+        bindings.set("c", "d");
+        bindings.set("12", "13");
+
+        auto exe = compiler->compile<openvdb::ax::VolumeExecutable>("");
+        CPPUNIT_ASSERT_NO_THROW(exe->setSettingsFromCLI(cli));
+
+        Index min,max;
+        exe->getTreeExecutionLevel(min, max);
+        CPPUNIT_ASSERT_EQUAL(defaultMinLevel, min);
+        CPPUNIT_ASSERT_EQUAL(defaultMaxLevel, max);
+        CPPUNIT_ASSERT_EQUAL(defaultCreateMissing, exe->getCreateMissing());
+        CPPUNIT_ASSERT_EQUAL(defaultTileStream, exe->getActiveTileStreaming());
+        CPPUNIT_ASSERT_EQUAL(defaultValueIter, exe->getValueIterator());
+        CPPUNIT_ASSERT_EQUAL(defaultGrain, exe->getGrainSize());
+        CPPUNIT_ASSERT_EQUAL(defaultTileGrain, exe->getActiveTileStreamingGrainSize());
+        CPPUNIT_ASSERT_EQUAL(bindings, exe->getAttributeBindings());
+    }
+
+    // multiple
+    {
+        CLI cli = CreateCLI("--volume-grain 5:10 --create-missing OFF");
+        auto exe = compiler->compile<openvdb::ax::VolumeExecutable>("");
+        CPPUNIT_ASSERT_NO_THROW(exe->setSettingsFromCLI(cli));
+
+        Index min,max;
+        exe->getTreeExecutionLevel(min, max);
+        CPPUNIT_ASSERT_EQUAL(defaultMinLevel, min);
+        CPPUNIT_ASSERT_EQUAL(defaultMaxLevel, max);
+        CPPUNIT_ASSERT_EQUAL(false, exe->getCreateMissing());
+        CPPUNIT_ASSERT_EQUAL(defaultTileStream, exe->getActiveTileStreaming());
+        CPPUNIT_ASSERT_EQUAL(defaultValueIter, exe->getValueIterator());
+        CPPUNIT_ASSERT_EQUAL(size_t(5), exe->getGrainSize());
+        CPPUNIT_ASSERT_EQUAL(size_t(10), exe->getActiveTileStreamingGrainSize());
+        CPPUNIT_ASSERT_EQUAL(defaultBindings, exe->getAttributeBindings());
+
+        cli = CreateCLI("--tile-stream ON --node-iter OFF --tree-level 2:3 --volume-grain 10:20 --create-missing ON --bindings a:b");
+        ax::AttributeBindings bindings;
+        bindings.set("a", "b");
+
+        CPPUNIT_ASSERT_NO_THROW(exe->setSettingsFromCLI(cli));
+        exe->getTreeExecutionLevel(min, max);
+        CPPUNIT_ASSERT_EQUAL(Index(2), min);
+        CPPUNIT_ASSERT_EQUAL(Index(3), max);
+        CPPUNIT_ASSERT_EQUAL(true, exe->getCreateMissing());
+        CPPUNIT_ASSERT_EQUAL(openvdb::ax::VolumeExecutable::Streaming::ON, exe->getActiveTileStreaming());
+        CPPUNIT_ASSERT_EQUAL(openvdb::ax::VolumeExecutable::IterType::OFF, exe->getValueIterator());
+        CPPUNIT_ASSERT_EQUAL(size_t(10), exe->getGrainSize());
+        CPPUNIT_ASSERT_EQUAL(size_t(20), exe->getActiveTileStreamingGrainSize());
+        CPPUNIT_ASSERT_EQUAL(bindings, exe->getAttributeBindings());
+    }
+}
