@@ -59,6 +59,7 @@ public:
     CPPUNIT_TEST(fit);
     CPPUNIT_TEST(floormod);
     CPPUNIT_TEST(hash);
+    CPPUNIT_TEST(hsvtorgb);
     CPPUNIT_TEST(identity3);
     CPPUNIT_TEST(identity4);
     CPPUNIT_TEST(intrinsic);
@@ -81,6 +82,7 @@ public:
     CPPUNIT_TEST(radians);
     CPPUNIT_TEST(rand);
     CPPUNIT_TEST(rand32);
+    CPPUNIT_TEST(rgbtohsv);
     CPPUNIT_TEST(sign);
     CPPUNIT_TEST(signbit);
     CPPUNIT_TEST(simplexnoise);
@@ -118,6 +120,7 @@ public:
     void fit();
     void floormod();
     void hash();
+    void hsvtorgb();
     void identity3();
     void identity4();
     void intrinsic();
@@ -140,6 +143,7 @@ public:
     void radians();
     void rand();
     void rand32();
+    void rgbtohsv();
     void sign();
     void signbit();
     void simplexnoise();
@@ -149,8 +153,8 @@ public:
     void tanh();
     void trace();
     void transform();
-    void truncatemod();
     void transpose();
+    void truncatemod();
 };
 
 CPPUNIT_TEST_SUITE_REGISTRATION(TestStandardFunctions);
@@ -169,6 +173,8 @@ inline void testFunctionOptions(unittest_util::AXTestHarness& harness,
     const ast::Tree::Ptr syntaxTree = ast::parse(code.c_str());
     timer.stop();
 
+    CPPUNIT_ASSERT_MESSAGE(syntaxTree, "Invalid AX passed to testFunctionOptions.");
+
     // @warning  the first execution can take longer due to some llvm startup
     //           so if you're profiling a single function be aware of this.
     //           This also profiles execution AND compilation.
@@ -269,7 +275,7 @@ TestStandardFunctions::abs()
     mHarness.addAttributes<int32_t>(unittest_util::nameSequence("test", 3), {
         std::abs(-3), std::abs(3), std::abs(0)
     });
-    mHarness.addAttribute<int64_t>("test4", std::abs(-2147483649l));
+    mHarness.addAttribute<int64_t>("test4", std::llabs(-2147483649LL));
     mHarness.addAttribute<float>("test5", std::abs(0.3f));
     mHarness.addAttribute<float>("test6", std::abs(-0.3f));
     mHarness.addAttribute<double>("test7", std::abs(1.79769e+308));
@@ -653,6 +659,77 @@ TestStandardFunctions::hash()
     testFunctionOptions(mHarness, "hash");
 }
 
+void
+TestStandardFunctions::hsvtorgb()
+{
+    auto axmod = [](auto D, auto d) -> auto {
+        auto r = std::fmod(D, d);
+        if ((r > 0 && d < 0) || (r < 0 && d > 0)) r = r+d;
+        return r;
+    };
+
+    // HSV to RGB conversion. Taken from OpenEXR's ImathColorAlgo
+    // @note  AX adds flooredmod of input hue to wrap to [0,1] domain
+    // @note  AX also clamp saturation to [0,1]
+    auto convert = [&](const openvdb::Vec3d& hsv) {
+        double hue = hsv.x();
+        double sat = hsv.y();
+        double val = hsv.z();
+        openvdb::Vec3d rgb(0.0);
+
+        // additions
+        hue = axmod(hue, 1.0);
+        sat = std::max(0.0, sat);
+        sat = std::min(1.0, sat);
+        //
+
+        if (hue == 1) hue = 0;
+        else          hue *= 6;
+
+        int i = int(std::floor(hue));
+        double f = hue - i;
+        double p = val * (1 - sat);
+        double q = val * (1 - (sat * f));
+        double t = val * (1 - (sat * (1 - f)));
+
+        switch (i) {
+            case 0:
+                rgb[0] = val; rgb[1] = t; rgb[2] = p;
+                break;
+            case 1:
+                rgb[0] = q; rgb[1] = val; rgb[2] = p;
+                break;
+            case 2:
+                rgb[0] = p; rgb[1] = val; rgb[2] = t;
+                break;
+            case 3:
+                rgb[0] = p; rgb[1] = q; rgb[2] = val;
+                break;
+            case 4:
+                rgb[0] = t; rgb[1] = p; rgb[2] = val;
+                break;
+            case 5:
+                rgb[0] = val; rgb[1] = p; rgb[2] = q;
+                break;
+        }
+
+        return rgb;
+    };
+
+    const std::vector<openvdb::Vec3d> values{
+        convert({0,0,0}),
+        convert({1,1,1}),
+        convert({5.8,1,1}),
+        convert({-0.1,-0.5,10}),
+        convert({-5.1,10.5,-5}),
+        convert({-7,-11.5,5}),
+        convert({0.5,0.5,0.5}),
+        convert({0.3,1.0,10.0})
+    };
+    mHarness.addAttributes<openvdb::Vec3d>(unittest_util::nameSequence("test", 8), values);
+    testFunctionOptions(mHarness, "hsvtorgb");
+}
+
 void
 TestStandardFunctions::identity3()
 {
@@ -1118,6 +1195,46 @@ TestStandardFunctions::rand32()
     testFunctionOptions(mHarness, "rand32");
 }
 
+void
+TestStandardFunctions::rgbtohsv()
+{
+    // RGB to HSV conversion. Taken from OpenEXR's ImathColorAlgo
+    auto convert = [](const openvdb::Vec3d& rgb) {
+        const double& x = rgb.x();
+        const double& y = rgb.y();
+        const double& z = rgb.z();
+
+        double max   = (x > y) ? ((x > z) ? x : z) : ((y > z) ? y : z);
+        double min   = (x < y) ? ((x < z) ? x : z) : ((y < z) ? y : z);
+        double range = max - min;
+        double val   = max;
+        double sat   = 0;
+        double hue   = 0;
+
+        if (max != 0) sat = range / max;
+        if (sat != 0)
+        {
+            double h;
+            if (x == max)       h = (y - z) / range;
+            else if (y == max)  h = 2 + (z - x) / range;
+            else                h = 4 + (x - y) / range;
+            hue = h / 6.;
+            if (hue < 0.) hue += 1.0;
+        }
+
+        return openvdb::Vec3d(hue, sat, val);
+    };
+
+    const std::vector<openvdb::Vec3d> values{
+        convert({0,0,0}),
+        convert({1,1,1}),
+        convert({20.5,40.3,100.1}),
+        convert({-10,1.3,0.25})
+    };
+    mHarness.addAttributes<openvdb::Vec3d>(unittest_util::nameSequence("test", 4), values);
+    testFunctionOptions(mHarness, "rgbtohsv");
+}
+
 void
 TestStandardFunctions::sign()
 {
