@@ -399,6 +399,14 @@ Activity Difference:\n\
             " voxel values are considered equal to the background"
             " if they differ by less than this tolerance."));
 
+    // Prune Degenerate Tiles
+    parms.add(hutil::ParmFactory(PRM_TOGGLE, "prunedegenerate", "Prune Degenerate Tiles")
+        .setDefault(PRMzeroDefaults)
+        .setDocumentation(
+            "When SDF CSG operations result in a degenerancy, such as a VDB\n"
+            "subtracted from itself, clear the tile rather than having ghost\n"
+            "bands.\n"));
+
     // Prune toggle
     parms.add(hutil::ParmFactory(PRM_TOGGLE, "prune", "Prune")
         .setDefault(PRMoneDefaults)
@@ -964,7 +972,7 @@ struct SOP_OpenVDB_Combine::CombineOp
     UT_String aGridName, bGridName;
     hvdb::GridCPtr aBaseGrid, bBaseGrid;
     hvdb::GridPtr outGrid;
-    hvdb::Interrupter interrupt;
+    hvdb::HoudiniInterrupter interrupt;
 
     CombineOp(): self(nullptr) {}
 
@@ -1013,7 +1021,7 @@ struct SOP_OpenVDB_Combine::CombineOp
 
             try {
                 dest = openvdb::tools::doLevelSetRebuild(src, /*iso=*/ZERO,
-                    /*exWidth=*/halfWidth, /*inWidth=*/halfWidth, &refXform, &interrupt);
+                    /*exWidth=*/halfWidth, /*inWidth=*/halfWidth, &refXform, &interrupt.interrupter());
             } catch (openvdb::TypeError&) {
                 self->addWarning(SOP_MESSAGE, ("skipped rebuild of level set grid "
                     + src.getName() + " of type " + src.type()).c_str());
@@ -1028,9 +1036,9 @@ struct SOP_OpenVDB_Combine::CombineOp
             dest->setTransform(refXform.copy());
             using namespace openvdb;
             switch (order) {
-            case 0: tools::resampleToMatch<tools::PointSampler>(src, *dest, interrupt); break;
-            case 1: tools::resampleToMatch<tools::BoxSampler>(src, *dest, interrupt); break;
-            case 2: tools::resampleToMatch<tools::QuadraticSampler>(src, *dest, interrupt); break;
+            case 0: tools::resampleToMatch<tools::PointSampler>(src, *dest, interrupt.interrupter()); break;
+            case 1: tools::resampleToMatch<tools::BoxSampler>(src, *dest, interrupt.interrupter()); break;
+            case 2: tools::resampleToMatch<tools::QuadraticSampler>(src, *dest, interrupt.interrupter()); break;
             }
         }
         return dest;
@@ -1159,19 +1167,19 @@ struct SOP_OpenVDB_Combine::CombineOp
     }
 
     template <typename GridT>
-    void doUnion(GridT &result, GridT &temp)
+    void doUnion(GridT &result, GridT &temp, bool prunedegen)
     {
-        openvdb::tools::csgUnion(result, temp);
+        openvdb::tools::csgUnion(result, temp, /*prune*/true, /*prunedgen*/prunedegen);
     }
     template <typename GridT>
-    void doIntersection(GridT &result, GridT &temp)
+    void doIntersection(GridT &result, GridT &temp, bool prunedegen)
     {
-        openvdb::tools::csgIntersection(result, temp);
+        openvdb::tools::csgIntersection(result, temp, /*prune*/true, /*prunedgen*/prunedegen);
     }
     template <typename GridT>
-    void doDifference(GridT &result, GridT &temp)
+    void doDifference(GridT &result, GridT &temp, bool prunedegen)
     {
-        openvdb::tools::csgDifference(result, temp);
+        openvdb::tools::csgDifference(result, temp, /*prune*/true, /*prunedgen*/prunedegen);
     }
 
     // Combine two grids of the same type.
@@ -1281,19 +1289,22 @@ struct SOP_OpenVDB_Combine::CombineOp
             case OP_UNION:
                 MulAdd<GridT>(aMult).process(*aGrid, resultGrid);
                 MulAdd<GridT>(bMult).process(*bGrid, tempGrid);
-                doUnion(*resultGrid, *tempGrid);
+                doUnion(*resultGrid, *tempGrid,
+                        self->evalInt("prunedegenerate", 0, self->getTime()));
                 break;
 
             case OP_INTERSECTION:
                 MulAdd<GridT>(aMult).process(*aGrid, resultGrid);
                 MulAdd<GridT>(bMult).process(*bGrid, tempGrid);
-                doIntersection(*resultGrid, *tempGrid);
+                doIntersection(*resultGrid, *tempGrid,
+                        self->evalInt("prunedegenerate", 0, self->getTime()));
                 break;
 
             case OP_DIFFERENCE:
                 MulAdd<GridT>(aMult).process(*aGrid, resultGrid);
                 MulAdd<GridT>(bMult).process(*bGrid, tempGrid);
-                doDifference(*resultGrid, *tempGrid);
+                doDifference(*resultGrid, *tempGrid,
+                        self->evalInt("prunedegenerate", 0, self->getTime()));
                 break;
 
             case OP_REPLACE:
@@ -1445,15 +1456,15 @@ struct SOP_OpenVDB_Combine::CombineOp
 }; // struct CombineOp
 
 template <>
-void SOP_OpenVDB_Combine::CombineOp::doUnion(openvdb::BoolGrid &result, openvdb::BoolGrid &temp)
+void SOP_OpenVDB_Combine::CombineOp::doUnion(openvdb::BoolGrid &result, openvdb::BoolGrid &temp, bool prunedegen)
 {
 }
 template <>
-void SOP_OpenVDB_Combine::CombineOp::doIntersection(openvdb::BoolGrid &result, openvdb::BoolGrid &temp)
+void SOP_OpenVDB_Combine::CombineOp::doIntersection(openvdb::BoolGrid &result, openvdb::BoolGrid &temp, bool prunedegen)
 {
 }
 template <>
-void SOP_OpenVDB_Combine::CombineOp::doDifference(openvdb::BoolGrid &result, openvdb::BoolGrid &temp)
+void SOP_OpenVDB_Combine::CombineOp::doDifference(openvdb::BoolGrid &result, openvdb::BoolGrid &temp, bool prunedegen)
 {
 }
 
@@ -1521,12 +1532,10 @@ SOP_OpenVDB_Combine::Cache::combineGrids(
     compOp.bBaseGrid = bGrid;
     compOp.aGridName = aGridName;
     compOp.bGridName = bGridName;
-    compOp.interrupt = hvdb::Interrupter();
+    compOp.interrupt = hvdb::HoudiniInterrupter();
 
     int success = false;
-    if (needA || UTvdbGetGridType(*aGrid) == UTvdbGetGridType(*bGrid)) {
-        success = aGrid->apply<hvdb::VolumeGridTypes>(compOp);
-    }
+    success = (needA ? aGrid : bGrid)->apply<hvdb::VolumeGridTypes>(compOp);
     if (!success || !compOp.outGrid) {
         std::ostringstream ostr;
         if (aGrid->type() == bGrid->type()) {
