@@ -17,6 +17,7 @@
 #include <openvdb_houdini/UT_VDBUtils.h> // for UTvdbGridCast()
 #include <openvdb_houdini/SOP_NodeVDB.h>
 #include <openvdb/openvdb.h>
+#include <openvdb/math/Math.h>
 #include <openvdb/tools/GridTransformer.h>
 #include <openvdb/tools/LevelSetRebuild.h>
 #include <openvdb/tools/VectorTransformer.h> // for transformVectors()
@@ -208,7 +209,7 @@ Using Voxel Scale Only:\n\
         .setTooltip(
             "Apply the resampling transform to the voxel values of vector-valued VDBs,"
             " in accordance with those VDBs'"
-            " [Vector Type|https://academysoftwarefoundation.github.io/openvdb/overview.html#secGrid]"
+            " [Vector Type|https://www.openvdb.org/documentation/doxygen/overview.html#secGrid]"
             " attributes."));
 
     // Level set rebuild toggle
@@ -405,11 +406,11 @@ struct RebuildOp
 
         const ValueT halfWidth = ValueT(grid.background() * (1.0 / grid.voxelSize()[0]));
 
-        hvdb::Interrupter interrupter;
+        hvdb::HoudiniInterrupter interrupter;
         try {
             outGrid = openvdb::tools::doLevelSetRebuild(grid,
                 /*isovalue=*/openvdb::zeroVal<ValueT>(),
-                /*exWidth=*/halfWidth, /*inWidth=*/halfWidth, &xform, &interrupter);
+                /*exWidth=*/halfWidth, /*inWidth=*/halfWidth, &xform, &interrupter.interrupter());
         } catch (openvdb::TypeError&) {
             addWarning("skipped rebuild of level set grid " + grid.getName()
                 + " of type " + grid.type());
@@ -467,7 +468,7 @@ SOP_OpenVDB_Resample::Cache::cookVDBSop(OP_Context& context)
 
         const openvdb::Vec3R
             translate = evalVec3R("t", time),
-            rotate = (M_PI / 180.0) * evalVec3R("r", time),
+            rotate = (openvdb::math::pi<double>() / 180.0) * evalVec3R("r", time),
             scale = evalVec3R("s", time),
             pivot = evalVec3R("p", time);
         const float
@@ -627,8 +628,8 @@ SOP_OpenVDB_Resample::Cache::cookVDBSop(OP_Context& context)
                 } else {
                     // Use the resample tool to sample the input grid into the output grid.
 
-                    hvdb::Interrupter interrupter;
-                    xform.setInterrupter(interrupter);
+                    hvdb::HoudiniInterrupter interrupter;
+                    xform.setInterrupter(interrupter.interrupter());
 
                     if (curOrder == 0) {
                         hvdb::GridTransformOp<openvdb::tools::PointSampler> op(outGrid, xform);
